from pathlib import Path
from zipfile import ZipFile
import glob


p=Path("ecommerce")

list1=[x for x in p.glob('*')]  #搜索主文件夹中的所有文件名和子文件夹名（主文件夹中有什么）
list2=[x for x in p.glob('*.*')]  #搜索主文件夹中所有的文件（只是文件，结果不包括子文件夹名）（主文件夹中有什么文件）
list3=[x for x in p.glob('*.py')]  #搜索主文件夹中所有的.py文件（主文件夹中有什么.py文件）
list4=[x for x in p.glob('**')]  #搜索主文件夹名和所有子文件夹名(包括子文件夹的子文件夹)（这个file有哪些主，子文件夹）
list5=[x for x in p.glob('**/*')]  #搜索所有子文件夹名,以及主文件夹和子文件夹中的所有文件(包括子文件夹的子文件夹)
list6=[x for x in p.rglob('*')]  #一样 （这个里面有什么）
list7=[x for x in p.rglob('*.*')]  #（这个里面有什么文件）
list8=[x for x in p.glob('**/*.py')]  #搜索所有主文件夹和子文件夹中的.py文件 (包括子文件夹的子文件夹)
list9=[x for x in p.rglob('*.py')]  #一样（这个里面有什么.py文件）
print(list5)
print(list6)
print(list7)


#!/usr/bin/python

import smtplib
sender = 'rachelhanlj@outlook.com'
receivers = ['rachelhanlj@163.com']

#smtp
smtpHost = 'smtp.office365.com'
smtpPort = 587
password = "Anhan12!" 

subject = "outlook email test"
# Add the From: and To: headers at the start!
message = ("From: %s\r\nTo: %s\r\nSubject: %s\r\n\r\n"
       % (sender, ", ".join(receivers), subject))

message += """This is a test e-mail message."""

print (message)

try:
    smtpObj = smtplib.SMTP(smtpHost, smtpPort)
    #smtpObj.set_debuglevel(1)
    smtpObj.ehlo()
    smtpObj.starttls()
    smtpObj.ehlo()    

    smtpObj.login(sender,password)
    smtpObj.sendmail(sender, receivers, message)
    smtpObj.quit()
    print ("Successfully sent email")
except SMTPException:
    print ("Error: unable to send email")




from email.mime.multipart import MIMEMultipart
#从email包中（子文件夹）的mine包（Multi-purpose Internet Mail Extensions 是一个定义邮件信息的格式标准）的multipart多方模块，引入MIMEMultipart 类 用这个类可以 发送HTML和TEXT的电子邮件信息

message=MIMEMultipart()  #调用这个类
message["from"]="rachelhanlj@outlook.com"
message["to"]="rachelhanlj@163.com"
message["subject"]="This is a good test"


from pathlib import Path
from email.mime.image import MIMEImage    #如果想发送图片
message.attach(MIMEImage(Path("IMG_0576.JPG").read_bytes()))

from email.mime.text import MIMEText   #如果想发送文字信息
message.attach(MIMEText("Body,Hello World"))

from string import Template  #如果想发送模板   注意：如果同时有多行message.attach(MIMEText()会变成附件，不要这样(最好都写在模板里)
template=Template(Path("template.html").read_text())
message.attach(MIMEText(template.substitute({"name":"Rachel","times":2,}),"html")) 
#这个HTML不写，信息就会变成和模板编辑器里一样的东西，要写上才会变成正常文字格式


import smtplib
with smtplib.SMTP('smtp.office365.com',587) as smtp:
    smtp.ehlo()     #和服务器打招呼
    smtp.starttls()   #把smtp放在tls模式下 transport layer security。和服务器打完招呼后发送安全协议  因为这个括号debug了一整天

    smtp.login("rachelhanlj@outlook.com","Anhan12!")
    smtp.send_message(message)
    print("sent")      #为了确认是否发送（程序运转是否正常）可以不写

